@@ -189,7 +189,7 @@ class Dataset(Collection):
             try:
                 file_length = int(r.headers.get("content-length"))
                 pbar = tqdm(total=file_length, initial=0, unit="B", unit_scale=True)
-            except:
+            except Exception:
                 warnings.warn("Failed to create download progress bar", RuntimeWarning)
 
         with open(local_path, "wb") as fd:
@@ -1102,6 +1102,7 @@ class Dataset(Collection):
         include: Optional[List[str]] = None,
         merge: bool = False,
         raise_on_plan: Union[str, bool] = False,
+        status: Optional[List[str]] = None,
     ) -> "pd.Series":
         """
         Runs a query based on an indexer which is index : molecule_id
@@ -1118,6 +1119,8 @@ class Dataset(Collection):
             Sum compound queries together, useful for mixing results
         raise_on_plan : Union[str, bool], optional
             Raises a KeyError is True or string if a multi-stage plan is detected.
+        status : List[str]
+            Include only records with these statuses. By default, obtain all records
 
         Returns
         -------
@@ -1151,7 +1154,7 @@ class Dataset(Collection):
             records: List[ResultRecord] = []
             for i in range(0, len(molecules), self.client.query_limit):
                 query_set["molecule"] = molecules[i : i + self.client.query_limit]
-                records.extend(self.client.query_results(**query_set))
+                records.extend(self.client.query_results(**query_set, status=status))
 
             if include is None:
                 records = [{"molecule": x.molecule, "record": x} for x in records]
@@ -1315,7 +1318,7 @@ class Dataset(Collection):
             self.data.alias_keywords[program] = {}
 
         if alias in self.data.alias_keywords[program]:
-            raise KeyError("Alias '{}' already set for program {}.".format(alias, keyword.program))
+            raise KeyError("Alias '{}' already set for program {}.".format(alias, program))
 
         self._new_keywords[(program, alias)] = keyword
 
@@ -1564,6 +1567,7 @@ class Dataset(Collection):
         include: Optional[List[str]] = None,
         subset: Optional[Union[str, Set[str]]] = None,
         merge: bool = False,
+        status: Optional[List[str]] = None,
     ) -> Union[pd.DataFrame, "ResultRecord"]:
         """
         Queries full ResultRecord objects from the database.
@@ -1585,6 +1589,8 @@ class Dataset(Collection):
         merge : bool
             Merge multiple results into one (as in the case of DFT-D3).
             This only works when include=['return_results'], as in get_values.
+        status : List[str]
+            Include only records with these statuses. By default, obtain all records
 
         Returns
         -------
@@ -1596,7 +1602,7 @@ class Dataset(Collection):
             raise KeyError(f"Requested query ({name}) did not match a known record.")
 
         indexer = self._molecule_indexer(subset=subset, force=True)
-        df = self._get_records(indexer, history, include=include, merge=merge)
+        df = self._get_records(indexer, history, include=include, merge=merge, status=status)
 
         if not merge and len(df) == 1:
             df = df[0]
@@ -1632,6 +1638,7 @@ class Dataset(Collection):
         *,
         keywords: Optional[str] = None,
         program: Optional[str] = None,
+        subset: Optional[Set[str]] = None,
         tag: Optional[str] = None,
         priority: Optional[str] = None,
         protocols: Optional[Dict[str, Any]] = None,
@@ -1656,6 +1663,8 @@ class Dataset(Collection):
         protocols: Optional[Dict[str, Any]], optional
             Protocols for store more or less data per field. Current valid
             protocols: {'wavefunction'}
+        subset : Set[str], optional
+            Computes only a subset of the dataset.
 
         Returns
         -------
@@ -1668,7 +1677,10 @@ class Dataset(Collection):
         self.get_entries(force=True)
         compute_keys = {"program": program, "method": method, "basis": basis, "keywords": keywords}
 
-        molecule_idx = [e.molecule_id for e in self.data.records]
+        if subset:
+            molecule_idx = set(subset)
+        else:
+            molecule_idx = [e.molecule_id for e in self.data.records]
 
         ret = self._compute(compute_keys, molecule_idx, tag, priority, protocols)
         self.save()
